@@ -1,19 +1,20 @@
 import logging
 import warnings
-from typing import Any
+from typing import Union
 
+from _pytest.config import Config
 from pydantic import ValidationError
 
-from pytest_zebrunner.hooks import PytestZebrunnerHooks
-from pytest_zebrunner.settings import ZebrunnerSettings
+from pytest_zebrunner.hooks import PytestHooks, PytestXdistHooks
+from pytest_zebrunner.settings import load_settings
 
 logger = logging.getLogger(__name__)
 
 
-def pytest_configure(config: Any) -> None:
+def pytest_configure(config: Config) -> None:
 
     try:
-        settings = ZebrunnerSettings()
+        settings = load_settings()
     except ValidationError as exc:
         field_errors = "\n".join([f"\033[93m {e['loc'][0]}\033[0m - {e['msg']}" for e in exc.errors()])
         warnings.warn(
@@ -24,9 +25,13 @@ def pytest_configure(config: Any) -> None:
         )
         return
 
-    if settings.reporting_enabled:
-        hooks = PytestZebrunnerHooks()
-        config.pluginmanager.register(hooks)
+    if settings.enabled:
+        hooks: Union[PytestHooks, PytestXdistHooks]
+        if config.pluginmanager.has_plugin("xdist") and any([x == "-n" for x in config.invocation_params.args]):
+            hooks = PytestXdistHooks()
+        else:
+            hooks = PytestHooks()
 
+        config.pluginmanager.register(hooks)
         config.addinivalue_line("markers", "maintainer(name): Email or nickname of test maintainer")
         config.addinivalue_line("markers", "label(name, value): Test label")
