@@ -13,6 +13,9 @@ class SeleniumSession:
 
     def start_session(self, session_id: str, capabilities: dict, desired_capabilities: dict) -> None:
         self._active_sessions[session_id] = {"related_tests": []}
+        if zebrunner_context.test_is_active:
+            self._active_sessions[session_id]["related_tests"].append(zebrunner_context.test_id)
+
         zebrunner_session_id = self.reporting_service.start_test_session(
             session_id, capabilities, desired_capabilities
         )
